@@ -214,7 +214,7 @@ mustbe(FILE * f, u_char ch)
 static int
 png(FILE * f, int *wp, int *hp)
 {
-	int l, w, h, d;
+	int l, w, h;
 	u_char l1, l2, l3, l4, w1, w2, w3, w4, h1, h2, h3, h4, d1;
 
 	if (!mustbe(f, 'P'))
@@ -275,7 +275,6 @@ png(FILE * f, int *wp, int *hp)
 	get(f, &h1);
 	if (!get(f, &d1))
 		return (0);
-	d = (int) d1;
 
 	*wp = w;
 	*hp = h;
